Overscan	SUBROUTINE
	lda #$02
	sta WSYNC								; end last scanline
	sta VBLANK								; turn of TIA

			
	lda #NTSC_OVERSCAN_TIME				; assume NTSC display ($1D)
	bit SWCHB								; check the right difficulty switch
	bpl .setOverscanTime					; if set to B then use NTSC settings
	lda #PAL_OVERSCAN_TIME				; else use PAL settings ($3A)
.setOverscanTime
	sta TIM64T

	lda gameState							; get the current game state
	beq DetermineClimberAllowedMotion
												; if the game isn't being played then
												; jump to the big wait
	jmp OverscanWait
DetermineClimberAllowedMotion	SUBROUTINE
	ldy #NUMGRP-1
	lda verPosP0
.determineWalkwayLoop
	cmp WalkwayValues,y
	beq .walkwayFound						; the climber is standing on a platform
	dey
	bpl .determineWalkwayLoop

	lda #%11011111
	bit playerState						; if the player was hit and no walkay was
	bmi .setAllowedMotion				; found make the player fall
	
	lda SWCHA								; don't allow horizontal movement but allow
	ora #%11000000							; vertical movement (climber is between
	bmi .setAllowedMotion				; platforms)
.walkwayFound
	lda #%11110000
	bit playerState
	bmi .setAllowedMotion
	and SWCHA								; allow horizontal movement
	
	sta allowedMotion
	
	tya										; y holds the walkway number
	and #%00000001							; mask all but bit 0
	asl										; multiply the value by 2
	tay										; this will now be used as an index for
												; odd/even walkways
	ldx #$00
.storeValidLadderValues
	lda LadderValuePointer,y
	sta ladderPointer,x
	iny
	inx
	cpx #$04
	bne .storeValidLadderValues
		
	ldy #$13
	lda horPosP0
.determineLadderNumber
	cmp (ladderPointer),y				; check and see if the climber's horizontal 
	beq .allowDownwardMotion			; position compared to the ladder values
	cmp (ladderPointer+2),y
	beq .allowUpwardMotion
	dey
	bpl .determineLadderNumber
	
	lda #%00110000							; don't allow vertical motion
	bne .setVerticalMotion
	
.allowUpwardMotion
	lda #%00100000
	bne .setVerticalMotion
	
.allowDownwardMotion
	lda #%00010000
	
.setVerticalMotion
	ora allowedMotion
	
.setAllowedMotion
	sta allowedMotion
	
CheckPlayerCollisions	SUBROUTINE
	lda CXP0FB								; player0/ball collision
	and #%01000000
	bne .playerBallCollision

	lda CXPPMM								; player0/player1 collision
	bmi .playerGirderCollision

	jmp OverscanWait
	
.playerGirderCollision
	tax
	lda #$FF
	and allowedMotion
	sta allowedMotion
	
	bit playerState
	bmi .playDeathSound
	
	stx playerState

	lda #$15
	sta soundIndex
	lda #$00
	sta soundCounter
	
	lda #$01
	sta duration

	
.playDeathSound
	dec duration
	beq .playNextDeathNote
	jmp OverscanWait
.playNextDeathNote	
	ldy #$0C
	lda #$0A
	sta duration
	ldx soundCounter
	inc soundCounter
	jsr PlaySound
	bne OverscanWait
	lda #$00
	sta playerState
	dec lives
	bpl .continueGame
	
	lda #GAME_OVER_STATE
	sta gameState
	lda #$7E
	sta attractMode
	lda #$1E
	sta frameCount
	bne .turnOffSound
	
.playerBallCollision
	bit playerState
	bvs .playSuccessSound
	
	sta playerState
	
	lda #$01
	sta duration
	
	lda #$06
	sta soundIndex
	
.playSuccessSound
	ldx #$FF
	stx allowedMotion
	
	ldy #$06
	dec duration
	bne OverscanWait
	
	lda #$0A
	sta duration
	
	lda soundIndex
	tax
	lda SuccessSoundTable,x
	
	jsr PlaySound
	bne OverscanWait
	
	lda gameSelection
	bpl .incrementLevel
	
	jsr SetGirderGraphics
	
	ldx #NUMGRP-1
.checkGirderGraphicsLoop
	lda girderGraphics,x
	beq .continueGame
	dex
	bpl .checkGirderGraphicsLoop
	
.incrementLevel
	lda backgroundColor					; change the background color to show the
	sec										; player they have advanced to the new level
	sbc #$4E
	sta backgroundColor
	
	lda platformColor
	adc #$3E
	sta platformColor
	
	clc
	sed
	lda level
	adc #$01
	sta level
	cld
	
	cmp #MAX_LEVEL
	bcc .continueGame

.continueGame
	jsr RestartLevel						; restart with the current level number
	
.turnOffSound
	lda #$00									; turn of the success sound
	ldx #$05
.turnOffSoundLoop
	sta AUDC0,x
	dex
	bpl .turnOffSoundLoop
	sta CXCLR

OverscanWait
	lda INTIM
	bne OverscanWait